@@ -238,7 +238,7 @@ def addhubgroup(db, groupName, groupDescription):
 	return gidNumber
 
 	
-def addhubuser(hubname, username, fname, lname, email, pw, joomlagid, joomlagidNumber, gid, gidNumber, joomlauserid, loginShell, homeDir, createGroup, skipldap):
+def addhubuser(hubname, username, fname, lname, email, pw, joomlagid, joomlagidNumber, gid, gidNumber, joomlauserid, loginShell, nocreatehome, homeDir, createGroup, skipldap):
 	# grab config options
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
@@ -271,10 +271,11 @@ def addhubuser(hubname, username, fname, lname, email, pw, joomlagid, joomlagidN
 		
 
 	# create home directory
-	rc, procStdOut, procStdErr = hubzero.utilities.misc.exShellCommand(["mkdir", homeDir, "--mode", "0750"])
-	print procStdOut
-	if rc:
-		print procStdErr
+	if not nocreatehome:
+		rc, procStdOut, procStdErr = hubzero.utilities.misc.exShellCommand(["mkdir", homeDir, "--mode", "0750"])
+		print procStdOut
+		if rc:
+			print procStdErr
 
 	
 	# set ownerships
